@@ -25,6 +25,8 @@
 
 #include <Lum/Private/ImportExport.h>
 
+#include <Lum/Base/DateTime.h>
+#include <Lum/Base/Reference.h>
 #include <Lum/Base/Status.h>
 
 namespace Lum {
@@ -57,7 +59,7 @@ namespace Lum {
 
       public:
         PathDescription(const std::wstring& description, const std::wstring& path);
-	virtual ~PathDescription();
+  virtual ~PathDescription();
       };
 
     private:
@@ -117,6 +119,68 @@ namespace Lum {
     };
 
     extern LUMAPI bool operator!=(const Path& a, const Path& b);
+
+    /**
+      Class for scanning of directory contents.
+     */
+    class LUMAPI DirScanner : public Referencable
+    {
+    public:
+      /**
+        Possisble access rights
+      */
+      enum Right
+      {
+        rightRead    = 1 << 0,
+        rightWrite   = 1 << 1,
+        rightExecute = 1 << 2
+      };
+
+      /**
+        Values of an found directory entry
+      */
+      class LUMAPI Entry
+      {
+      public:
+        std::wstring     name;
+        bool             isDir;
+        bool             isLink;
+        bool             isHidden;
+
+        unsigned long    size;
+        SystemTime       timeModification;
+
+        unsigned short   user;
+        unsigned short   group;
+        unsigned short   other;
+      };
+
+    protected:
+      Path path;
+
+    public:
+      /**
+        Factory method for creating a scanner for the current
+        operating system.
+       */
+      static DirScanner* Create(const Path& path);
+
+    protected:
+      DirScanner(const Path& path);
+
+    public:
+      virtual ~DirScanner();
+
+      /**
+        Scan for the next (the first) entry. Returns false, if there
+        are no more entries. In this case check status, if this was the natural
+        end of the directory or if there was some error while scanning.
+      */
+      virtual bool GetNext(Entry& entry, Status& status) = 0;
+    };
+
+    typedef Reference<DirScanner> DirScannerRef;
+
   }
 }
 
