@@ -57,9 +57,9 @@ namespace Lum {
     public:
       static const size_t colorCount = 12; //! Number of predefined colors
       static const size_t fontCount  =  2; //! Number of predefined fonts
-      static const size_t fillCount  = 27; //! Number of predefined fills
-      static const size_t frameCount = 38; //! Number of predefined frames
-      static const size_t imageCount = 30; //! Number of predefined images
+      static const size_t fillCount  = 28; //! Number of predefined fills
+      static const size_t frameCount = 39; //! Number of predefined frames
+      static const size_t imageCount = 29; //! Number of predefined images
 
     protected:
       class LUMAPI Timer
@@ -115,7 +115,8 @@ namespace Lum {
         menuPulldownBackgroundFillIndex    = 23, //! Background of a pulldown menu (entry in a menu strip)
         menuEntryBackgroundFillIndex       = 24, //! Background of a menu entry
         graphBackgroundFillIndex           = 25, //! Background of graph-like controls
-        toolbarBackgroundFillIndex         = 26  //! Background of a toolbar
+        toolbarBackgroundFillIndex         = 26, //! Background of a toolbar
+        labelBackgroundFillIndex           = 27  //! Background of an label
       };
 
       enum FrameIndex {
@@ -157,40 +158,40 @@ namespace Lum {
         valuebarFrameIndex        = 34, //! Frame around value bars
         groupFrameIndex           = 35, //! Frame for grouping a number of elements
         menuStripFrameIndex       = 36, //! Frame around a menu strip
-        menuPulldownFrameIndex    = 37  //! Frame around a pull down menu (entry ina menu strip)
+        menuPulldownFrameIndex    = 37, //! Frame around a pull down menu (entry ina menu strip)
+        labelFrameIndex           = 38  //! Frame around a label
       };
 
       enum ImageIndex {
-        checkImageIndex            =  0, //! Image of a check box
-        radioImageIndex            =  1, //! Image of a single radio button
-        hknobImageIndex            =  2, //! Image of a horizontal scrolling knob
-        vknobImageIndex            =  3, //! Image of a vertical scrolling knob
-        arrowLeftImageIndex        =  4, //! Image of a arrow pointing to the left side
-        arrowRightImageIndex       =  5, //! Image of a arrow pointing to the right side
-        arrowUpImageIndex          =  6, //! Image of a arrow pointing up
-        arrowDownImageIndex        =  7, //! Image of a arrow pointing down
-        arrowScrollLeftImageIndex  =  8, //! Image of a arrow for scroll bars pointing to the left side
-        arrowScrollRightImageIndex =  9, //! Image of a arrow for scroll bars pointing to the right side
-        arrowScrollUpImageIndex    = 10, //! Image of a arrow for scroll bars pointing up
-        arrowScrollDownImageIndex  = 11, //! Image of a arrow for scroll bars pointing down
-        comboImageIndex            = 12, //! Image for combo box popup (normally just an arrow)
-        comboEditButtonImageIndex  = 13, //! Image for combo box popup (normally just an arrow)
-        comboDividerImageIndex     = 14, //! Divider between content and image
-        treeExpanderImageIndex     = 15, //! Image for tree node (de-)expansion
-        hscaleKnobImageIndex       = 16, //! Horizontal slider knob
-        vscaleKnobImageIndex       = 17, //! Vertical slider knob
-        leftSliderImageIndex       = 18, //! Left (filled) part of the slider control
-        rightSliderImageIndex      = 19, //! Right (unfilled) part of the slider control
-        topSliderImageIndex        = 20, //! Top (unfilled) part of the slider control
-        bottomSliderImageIndex     = 21, //! bottom (filled) part of the slider control
-        menuDividerImageIndex      = 22, //! Divider between menu entry groups
-        menuSubImageIndex          = 23, //! Image for signaling a sub menu
+        hknobImageIndex            =  0, //! Image of a horizontal scrolling knob
+        vknobImageIndex            =  1, //! Image of a vertical scrolling knob
+        arrowLeftImageIndex        =  2, //! Image of a arrow pointing to the left side
+        arrowRightImageIndex       =  3, //! Image of a arrow pointing to the right side
+        arrowUpImageIndex          =  4, //! Image of a arrow pointing up
+        arrowDownImageIndex        =  5, //! Image of a arrow pointing down
+        arrowScrollLeftImageIndex  =  6, //! Image of a arrow for scroll bars pointing to the left side
+        arrowScrollRightImageIndex =  7, //! Image of a arrow for scroll bars pointing to the right side
+        arrowScrollUpImageIndex    =  8, //! Image of a arrow for scroll bars pointing up
+        arrowScrollDownImageIndex  =  9, //! Image of a arrow for scroll bars pointing down
+        comboImageIndex            = 10, //! Image for read only combo box popup (normally just an arrow)
+        comboEditButtonImageIndex  = 11, //! Image for editable combo box popup (normally just an arrow)
+        comboDividerImageIndex     = 12, //! Divider between content and image
+        treeExpanderImageIndex     = 13, //! Image for tree node (de-)expansion
+        hscaleKnobImageIndex       = 14, //! Horizontal slider knob
+        vscaleKnobImageIndex       = 15, //! Vertical slider knob
+        leftSliderImageIndex       = 16, //! Left (filled) part of the slider control
+        rightSliderImageIndex      = 17, //! Right (unfilled) part of the slider control
+        topSliderImageIndex        = 18, //! Top (unfilled) part of the slider control
+        bottomSliderImageIndex     = 19, //! bottom (filled) part of the slider control
+        menuDividerImageIndex      = 20, //! Divider between menu entry groups
+        menuSubImageIndex          = 21, //! Image for signaling a sub menu
+        menuCheckImageIndex        = 22,
+        menuRadioImageIndex        = 23,
         positiveImageIndex         = 24, //! Image for marking a positive action (e.g. for a button)
         negativeImageIndex         = 25, //! Image for marking a negative action (e.g. for a button)
         defaultImageIndex          = 26, //! Image for marking a default action (e.g. for a button)
         helpImageIndex             = 27, //! Image for marking a help action (e.g. for a button)
-        closeImageIndex            = 28, //! Image for closing widget
-        ledImageIndex              = 29  //! An image for a simple on/off LED
+        closeImageIndex            = 28  //! Image for closing widget
       };
 
       enum FontScale {
@@ -238,10 +239,7 @@ namespace Lum {
         spaceObjectBorder      =  4, //! Space between object border and its elements
         spaceIntraObject       =  5, //! Space between elements within an object
         spaceLabelObject       =  6, //! Space between an object and its label
-        spaceObjectSensibility =  7, //! Size of sensitive area around an object
-        spaceObjectMouseMove   =  8, //! Amount of space the mouse has to move before
-                                     //! a movement is detected (=> drag & drop).
-        spaceObjectDetail      =  9  //! Space for object visualizing details
+        spaceObjectDetail      =  7  //! Space for object visualizing details
       };
 
       enum ByteOrder {
