@@ -225,6 +225,9 @@ namespace Lum {
     virtual size_t GetHeight() const;
     //@}
 
+    virtual void RequestFocus();
+    virtual void UnrequestFocus();
+
   public:
     virtual ~Object();
 
@@ -329,8 +332,6 @@ namespace Lum {
     virtual void SetCanFocus(bool can);
     virtual void SetShowFocus(bool show);
 
-    virtual void RequestFocus();
-    virtual void UnrequestFocus();
     virtual bool RequestedFocus() const;
 
     virtual void SetRequestsKeyboard(bool request);
@@ -475,6 +476,9 @@ namespace Lum {
     Scrollable();
     ~Scrollable();
 
+    void SetHAdjustment(Model::Adjustment* adjustment);
+    void SetVAdjustment(Model::Adjustment* adjustment);
+
     Model::Adjustment* GetHAdjustment() const;
     Model::Adjustment* GetVAdjustment() const;
 
