@@ -29,14 +29,6 @@ namespace Lum {
   */
   class LUMAPI Radio : public ImageState
   {
-  public:
-    class Prefs : public ImageState::Prefs
-    {
-    public:
-      Prefs();
-      void Initialize();
-    };
-
   public:
     Radio();
   };
