@@ -1393,8 +1393,42 @@ namespace Lum {
     }
 
     /**
-    Set object to the current date (local time).
-    */
+     * Subtract b from a and return the number of days between them.
+     */
+    long operator-(const Calendar& a, const Calendar& b)
+    {
+      if (a==b) {
+        return 0;
+      }
+
+      if (b>a) {
+        return -(operator-(b,a));
+      }
+
+      // It is now same to assume that a>b...
+
+      long result=0;
+
+      Calendar cb(b);
+
+      while (cb.year<a.year) {
+        result+=cb.GetDaysOfCurrentYear()-cb.GetDayOfYear();
+        cb.AddDays(cb.GetDaysOfCurrentYear()-cb.GetDayOfYear());
+      }
+
+      result+=a.GetDayOfYear()-cb.GetDayOfYear();
+
+      return result;
+    }
+
+    void operator++(Calendar& a)
+    {
+      a.AddDays(1);
+    }
+
+    /**
+     * Set object to the current date (local time).
+     */
     void Calendar::SetToCurrent()
     {
       DateTime current;
@@ -1405,9 +1439,9 @@ namespace Lum {
     }
 
     /**
-    Sets the calendar object to the date represented by
-    the parameters dayOfMonth, month and year.
-    */
+     * Sets the calendar object to the date represented by
+     * the parameters dayOfMonth, month and year.
+     */
     void Calendar::SetDate(int dayOfMonth, int month, int year)
     {
       assert(IsValid(dayOfMonth,month,year));
@@ -1445,13 +1479,23 @@ namespace Lum {
     }
 
     /**
-    Returns the number of days the current month has.
-    */
+     * Returns the number of days the current month has.
+     */
     int Calendar::GetDaysOfCurrentMonth() const
     {
       return CalculateDaysOfMonth(month,year);
     }
 
+    int Calendar::GetDaysOfCurrentYear() const
+    {
+      if (IsLeapYear()) {
+        return 366;
+      }
+      else {
+        return 365;
+      }
+    }
+
     std::wstring Calendar::GetISO8601() const
     {
       std::wstring res;
@@ -1495,8 +1539,8 @@ namespace Lum {
     }
 
     /**
-    Move the year by \p years.
-    */
+     *Move the year by \p years.
+     */
     void Calendar::AddYears(int years)
     {
       year+=years;
@@ -1504,10 +1548,10 @@ namespace Lum {
     }
 
     /**
-    Move the date by months. If the resulting date is invalid, because
-    the resulting month has lesser days that the date hold before, these days
-    will be added wraped around to the next month.
-    */
+     * Move the date by months. If the resulting date is invalid, because
+     * the resulting month has lesser days that the date hold before, these days
+     * will be added wraped around to the next month.
+     */
     void Calendar::AddMonths(int months)
     {
       month+=months;
@@ -1515,8 +1559,8 @@ namespace Lum {
     }
 
     /**
-    Move the date by days.
-    */
+     * Move the date by days.
+     */
     void Calendar::AddDays(int days)
     {
       dayOfMonth+=days;
@@ -1524,8 +1568,8 @@ namespace Lum {
     }
 
     /**
-    Set the date to the easter sunday of the current year.
-    */
+     * Set the date to the easter sunday of the current year.
+     */
     void Calendar::GotoEasterSunday()
     {
       int golden,solar,lunar,pfm,dom,tmp,easter;
@@ -1571,11 +1615,11 @@ namespace Lum {
     }
 
     /**
-    Set the date to the date given in 'date'. 'date' has to follow the ISO8601 format,
-    which is defined as 'YYYY-MM-DD' where 'YYYY' stand for the four digit year,
-    'MM' stands for the two digit month (1..12) and 'DD' stand for the two digit day
-    (1..31).
-    */
+     * Set the date to the date given in 'date'. 'date' has to follow the ISO8601 format,
+     * which is defined as 'YYYY-MM-DD' where 'YYYY' stand for the four digit year,
+     * 'MM' stands for the two digit month (1..12) and 'DD' stand for the two digit day
+     * (1..31).
+     */
     bool Calendar::SetISO8601(const std::wstring& date)
     {
       int d,m,y;
