@@ -19,26 +19,14 @@
 
 #include <Lum/Boolean.h>
 
-#include <Lum/OS/Display.h>
+#include <Lum/OS/Theme.h>
 
 namespace Lum {
 
-  static Boolean::Prefs *prefs=new ::Lum::Boolean::Prefs();
-
-  Boolean::Prefs::Prefs()
-  : ImageState::Prefs(L"Boolean")
-  {
-    // no code
-  }
-
-  void Boolean::Prefs::Initialize()
-  {
-    ImageState::Prefs::Initialize();
-
-    image=OS::display->GetImage(OS::Display::checkImageIndex);
-  }
+  static ImageState::Prefs *prefs=new ::Lum::ImageState::Prefs(L"Boolean");
 
   Boolean::Boolean()
+   : ImageState(OS::Theme::objCheck)
   {
     SetPrefs(::Lum::prefs);
   }
