@@ -21,9 +21,11 @@
 
 #include <Lum/Base/DateTime.h>
 
+#include <Lum/OS/Theme.h>
+
 #include <Lum/Dialog.h>
 #include <Lum/Text.h>
-
+#include <iostream>
 namespace Lum {
 
   static Button::Prefs *prefs=new Button::Prefs();
@@ -73,6 +75,8 @@ namespace Lum {
 
     SetCanFocus(true);
     SetCanDrawMouseActive(true);
+
+    RequestFocus();
   }
 
   Button::Button(Object* object)
@@ -111,16 +115,9 @@ namespace Lum {
 
   size_t Button::GetBaseline() const
   {
-    assert(inited);
+    assert(inited && object!=NULL && object->HasBaseline());
 
-    if (object!=NULL && object->HasBaseline()) {
-      // We also assume that is vertically flexible
-
-      return frame->topBorder+object->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
-    }
-    else {
-      return 0;
-    }
+    return frame->topBorder+object->GetBaseline()+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
   }
 
   /**
@@ -221,8 +218,9 @@ namespace Lum {
     /* Let the frame calculate its size */
     switch (type) {
       case typeNormal:
+      /*
       SetFrame(prefs->frame);
-      SetBackground(dynamic_cast<Prefs*>(prefs)->background);
+      SetBackground(dynamic_cast<Prefs*>(prefs)->background);*/
       break;
     case typeDefault:
       SetFrame(dynamic_cast<Prefs*>(prefs)->defaultFrame);
@@ -270,7 +268,8 @@ namespace Lum {
       minHeight=object->GetOMinHeight();
     }
 
-    if (image.Valid()) {
+    if (image.Valid() && OS::display->GetTheme()->ShowButtonImages()) {
+
       minWidth+=image->GetWidth()+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
       width+=image->GetWidth()+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
       minHeight=std::max(minHeight,image->GetHeight());
@@ -288,10 +287,6 @@ namespace Lum {
       // No space around object
       break;
     default:
-      minWidth+=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
-      width+=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
-      minHeight+=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
-      height+=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
       break;
     }
 
@@ -376,14 +371,22 @@ namespace Lum {
   bool Button::HandleKeyEvent(const OS::KeyEvent& event)
   {
     if (event.type==OS::KeyEvent::down) {
-      if (event.key==OS::keySpace) {
+      if (event.key==OS::keySpace && model->IsInactive()) {
         model->Start();
-        Base::SystemTime::Sleep(1);
-        model->Finish();
 
         return true;
       }
     }
+    else if (event.type==OS::KeyEvent::up) {
+      if (event.key==OS::keySpace) {
+        if (event.qualifier==0 && model->IsStarted()) {
+          model->Finish();
+        }
+        else if (event.qualifier!=0 && model->IsStarted()) {
+          model->Cancel();
+        }
+      }
+    }
 
     return false;
   }
@@ -414,14 +417,10 @@ namespace Lum {
     case typeScroll:
       break;
     default:
-      x+=OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
-      y+=OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
-      width-=2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder);
-      height-=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
       break;
     }
 
-    if (image.Valid()) {
+    if (image.Valid() && OS::display->GetTheme()->ShowButtonImages()) {
       imageX=x;
       imageY=y+(height-image->GetHeight())/2;
       x+=image->GetWidth()+OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
@@ -480,7 +479,7 @@ namespace Lum {
       draw->SubClipRegion(object->GetOX(),object->GetOY(),
                           object->GetOWidth(),object->GetOHeight());
     }
-    if (image.Valid() && !image->GetAlpha()) {
+    if (image.Valid() && OS::display->GetTheme()->ShowButtonImages() && !image->GetAlpha()) {
       draw->SubClipRegion(imageX,imageY,
                           image->GetWidth(),image->GetHeight());
     }
@@ -488,13 +487,13 @@ namespace Lum {
     DrawBackground(x,y,w,h);
     draw->PopClip();
 
-    // DRaw object
+    // Draw object
     if (object!=NULL) {
       object->Draw(x,y,w,h);
     }
 
     // Draw optional image
-    if (image.Valid()) {
+    if (image.Valid() && OS::display->GetTheme()->ShowButtonImages()) {
       image->Draw(draw,imageX,imageY,image->GetWidth(),image->GetHeight());
     }
 
