@@ -203,23 +203,18 @@ namespace Lum {
                       dynamic_cast<Prefs*>(prefs)->buttonImage->GetHeight());
     }
     else {
-      minWidth=OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder)+
-               OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
+      minWidth=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
                dynamic_cast<Prefs*>(prefs)->divider->GetWidth()+
                OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
-               dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
-               OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
+               dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth();
 
       width=minWidth;
 
       minWidth+=value->GetOMinWidth();
       minWidth+=value->GetOWidth();
 
-      minHeight=2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder);
-      height=minHeight;
-
-      minHeight+=std::max(value->GetOMinHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
-      height+=std::max(value->GetOHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
+      minHeight=std::max(value->GetOMinHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
+      height=std::max(value->GetOHeight(),dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
     }
 
     Control::CalcSize();
@@ -376,17 +371,15 @@ namespace Lum {
       value->Resize(width-
                     dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()-
                     2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
-                    dynamic_cast<Prefs*>(prefs)->divider->GetWidth()-
-                    2*OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder),
+                    dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
                     height-2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
 
       if (dynamic_cast<Prefs*>(prefs)->imageRight) {
-        value->Move(x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder),
+        value->Move(x,
                     y+(height-value->GetOHeight()) / 2);
       }
       else {
-        value->Move(x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)+
-                    dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
+        value->Move(x+dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
                     2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
                      dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
                     y+(height-value->GetOHeight()) / 2);
@@ -466,17 +459,15 @@ namespace Lum {
       if (dynamic_cast<Prefs*>(prefs)->imageRight) {
         dynamic_cast<Prefs*>(prefs)->divider->Draw(draw,
                                                    this->x+width-
-                                                   OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)-
                                                    dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()-
                                                    OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
                                                    dynamic_cast<Prefs*>(prefs)->divider->GetWidth(),
-                                                   this->y+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder),
+                                                   this->y,
                                                    dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                   height-2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
+                                                   height);
 
         dynamic_cast<Prefs*>(prefs)->readOnlyImage->Draw(draw,
                                                          this->x+width-
-                                                         OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)-
                                                          dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
                                                          this->y+(height-dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight()) / 2,
                                                          dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
@@ -484,18 +475,17 @@ namespace Lum {
       }
       else {
         dynamic_cast<Prefs*>(prefs)->readOnlyImage->Draw(draw,
-                                                         x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder),
+                                                         x,
                                                          y+(height-dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight()) / 2,
                                                          dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
                                                          dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetHeight());
 
         dynamic_cast<Prefs*>(prefs)->divider->Draw(draw,
-                                                   x+OS::display->GetSpaceHorizontal(OS::Display::spaceObjectBorder)+
-                                                   dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
+                                                   x+dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth()+
                                                    OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
-                                                   this->y+OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder),
+                                                   this->y,
                                                    dynamic_cast<Prefs*>(prefs)->readOnlyImage->GetWidth(),
-                                                   height-2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
+                                                   height);
 
       }
     }
@@ -507,7 +497,7 @@ namespace Lum {
 
   void Combo::DrawFocus()
   {
-    if (value!=NULL) {
+    if (editable && value!=NULL) {
       value->SetShowFocus(true);
     }
 
@@ -516,7 +506,7 @@ namespace Lum {
 
   void Combo::HideFocus()
   {
-    if (value!=NULL) {
+    if (editable && value!=NULL) {
       value->SetShowFocus(false);
     }
     Control::HideFocus();
