@@ -26,6 +26,7 @@
 
 #include <Lum/OS/Driver.h>
 #include <Lum/OS/KeyboardHandler.h>
+#include <Lum/OS/Theme.h>
 
 #include <Lum/FrameGroup.h>
 
@@ -177,9 +178,6 @@ namespace Lum {
     if (object!=NULL && object!=current) {
       SetFocus(object);
     }
-    else {
-      SetFocus(NULL);
-    }
   }
 
   void Dialog::KeyHandler::SetFocusLast()
@@ -382,6 +380,7 @@ namespace Lum {
     AttachModel(window->GetPreInitAction());
     AttachModel(window->GetOpenedAction());
     AttachModel(window->GetEventAction());
+    AttachModel(window->GetGrabCancelAction());
     AttachModel(menuAction);
   }
 
@@ -392,6 +391,7 @@ namespace Lum {
     delete frame;
 
     UnattachModel(menuAction);
+    UnattachModel(window->GetGrabCancelAction());
     UnattachModel(window->GetEventAction());
     UnattachModel(window->GetOpenedAction());
     UnattachModel(window->GetPreInitAction());
@@ -758,11 +758,9 @@ namespace Lum {
     case OS::Window::typeSplash:
       /* Close the window, if it gets deactivated */
       if ((mouseEvent=dynamic_cast<OS::MouseEvent*>(event))!=NULL) {
-        if (mouseEvent->type==OS::MouseEvent::down) {
-          if (!window->CursorIsIn()) {
-            window->Exit();
-            return true;
-          }
+        if (mouseEvent->type==OS::MouseEvent::down && !window->CursorIsIn()) {
+          window->Exit();
+          return true;
         }
       }
       else if ((keyEvent=dynamic_cast<OS::KeyEvent*>(event))!=NULL) {
@@ -809,8 +807,8 @@ namespace Lum {
       }
       else if (mouseEvent->type==OS::MouseEvent::move &&
                mouseEvent->qualifier & Lum::OS::MouseEvent::button1 &&
-               (std::abs(mouseEvent->x-mouse1DownX)>(int)OS::display->GetSpaceHorizontal(OS::Display::spaceObjectMouseMove) ||
-                std::abs(mouseEvent->y-mouse1DownY)>(int)OS::display->GetSpaceVertical(OS::Display::spaceObjectMouseMove))) {
+               (std::abs(mouseEvent->x-mouse1DownX)>(int)OS::display->GetTheme()->GetMouseClickHoldSensitivity() ||
+                std::abs(mouseEvent->y-mouse1DownY)>(int)OS::display->GetTheme()->GetMouseClickHoldSensitivity())) {
         OS::display->RemoveTimer(menuAction);
       }
 
@@ -835,7 +833,7 @@ namespace Lum {
         mouseGrabHunting=false;
 
         if (mouseGrab!=NULL && mouseGrab->HandlesFocus()) {
-          keyHandler.SetFocus(dynamic_cast<Lum::Object*>(mouseGrab));
+          SetFocus(dynamic_cast<Lum::Object*>(mouseGrab));
         }
       }
       else if (mouseEvent->type==OS::MouseEvent::move) {
@@ -992,6 +990,17 @@ namespace Lum {
         mouseGrab=NULL;
       }
     }
+    else if (model==window->GetGrabCancelAction() && window->GetGrabCancelAction()->IsFinished()) {
+      // A child popup opened while we were handling mouse button grab events.
+      OS::display->RemoveTimer(menuAction);
+
+      mouseGrab=NULL;
+      mouseGrabHunting=false;
+      if (mouseActive!=NULL) {
+        mouseActive->MouseInactive();
+        mouseActive=NULL;
+      }
+    }
   }
 
   bool Dialog::IsOpen() const
