@@ -164,7 +164,7 @@ namespace Lum {
 
   bool Knob::HandleMouseEvent(const OS::MouseEvent& event)
   {
-    if (!visible || !adjustment.Valid() || !adjustment->IsEnabled()) {
+    if (!visible || !adjustment.Valid() || !adjustment->IsValid() || !adjustment->IsEnabled()) {
       return false;
     }
 
@@ -317,7 +317,7 @@ namespace Lum {
       }
 
       draw->selected=selected;
-      knob->Draw(x,y,w,h);
+      knob->Draw(knob->GetOX(),knob->GetOY(),knob->GetOWidth(),knob->GetOHeight());
       draw->selected=false;
 
       draw->activated=false;
@@ -358,8 +358,8 @@ namespace Lum {
       }
     }
     else if (model==adjustment && visible && adjustment.Valid() && adjustment->IsEnabled()) {
-      //Redraw();
-      Draw(this->x,this->y,this->width,this->height);
+      Redraw();
+      //Draw(this->x,this->y,this->width,this->height);
     }
   }
 }
