@@ -24,6 +24,7 @@
 #include <Lum/OS/Display.h>
 
 #include <Lum/Text.h>
+#include <Lum/TextLabel.h>
 
 namespace Lum {
   static Label::Prefs *prefs=new Label::Prefs(L"Label");
@@ -201,7 +202,7 @@ namespace Lum {
   void Label::AddLabel(Object* label, Object* object)
   {
     assert(label!=NULL && object!=NULL);
-    
+
     Entry entry;
 
     label->SetParent(this);
@@ -218,12 +219,12 @@ namespace Lum {
 
   void Label::AddLabel(const std::wstring& label, Object* object)
   {
-    AddLabel(new Text(label),object);
+    AddLabel(new TextLabel(label),object);
   }
 
   void Label::AddLabel(const std::wstring& label, const std::wstring& object)
   {
-    AddLabel(new Text(label),new Text(object));
+    AddLabel(new TextLabel(label),new Text(object));
   }
 
   void Label::SetLabelFlex(bool flex)
@@ -384,7 +385,15 @@ namespace Lum {
         else {
           iter->label->Move(x,pos+(iter->GetHeight()-iter->label->GetOHeight())/2);
         }
-        iter->object->Move(x+labelWidth+OS::display->GetSpaceHorizontal(OS::Display::spaceLabelObject),pos);
+        
+        if (iter->object->GetOHeight()<=iter->label->GetOHeight()) {
+          iter->object->Move(x+labelWidth+OS::display->GetSpaceHorizontal(OS::Display::spaceLabelObject),
+          pos+(iter->label->GetOHeight()-iter->object->GetOHeight())/2);
+        }
+        else {
+          iter->object->Move(x+labelWidth+OS::display->GetSpaceHorizontal(OS::Display::spaceLabelObject),
+          pos);
+        }
       }
 
       pos+=iter->GetHeight()+OS::display->GetSpaceVertical(OS::Display::spaceInterObject);
