@@ -88,8 +88,8 @@ namespace Lum {
       background=OS::display->GetFill(OS::Display::menuEntryBackgroundFillIndex);
 
       arrow=OS::display->GetImage(OS::Display::menuSubImageIndex);
-      check=OS::display->GetImage(OS::Display::checkImageIndex);
-      radio=OS::display->GetImage(OS::Display::radioImageIndex);
+      check=OS::display->GetImage(OS::Display::menuCheckImageIndex);
+      radio=OS::display->GetImage(OS::Display::menuRadioImageIndex);
       divider=OS::display->GetImage(OS::Display::menuDividerImageIndex);
     }
   };
@@ -849,8 +849,7 @@ namespace Lum {
   {
     selectable=true;
 
-    // TODO: Use special radio *menu* image!
-    image=OS::display->GetImage(OS::Display::checkImageIndex);
+    image=dynamic_cast<MenuEntryPrefs*>(prefs)->check;
   }
 
   bool BoolItem::SetModel(Base::Model* model)
@@ -928,8 +927,7 @@ namespace Lum {
   {
     selectable=true;
 
-    // TODO: Use special radio *menu* image!
-    image=OS::display->GetImage(OS::Display::radioImageIndex);
+    image=dynamic_cast<MenuEntryPrefs*>(prefs)->radio;
   }
 
   bool RadioItem::SetModel(Base::Model* model)
@@ -1457,7 +1455,7 @@ namespace Lum {
       y=window->GetY();
     }
 
-    if (strip==NULL) {
+    if (strip==NULL && parentMenu==NULL) {
       window->Grab(true);
     }
 
