@@ -623,114 +623,12 @@ namespace Lum {
 
       size_t Display::GetSpaceHorizontal(Space space) const
       {
-        switch (type) {
-          case typeTextual:
-            switch (space) {
-            case spaceWindowBorder:
-              return 0;
-            case spaceInterGroup:
-              return 1;
-            case spaceGroupIndent:
-              return 1;
-            case spaceInterObject:
-              return 0;
-            case spaceObjectBorder:
-              return 0;
-            case spaceIntraObject:
-              return 1;
-            case spaceLabelObject:
-              return 1;
-            case spaceObjectSensibility:
-              return 0;
-            case spaceObjectMouseMove:
-              return 1;
-            case spaceObjectDetail:
-              return 1;
-            }
-          break;
-          case  typeGraphical:
-            switch (space) {
-            case spaceWindowBorder:
-              return 12;
-            case spaceInterGroup:
-              return 18;
-            case spaceGroupIndent:
-              return 12;
-            case spaceInterObject:
-              return 6;
-            case spaceObjectBorder:
-              return 6;
-            case spaceIntraObject:
-              return 6;
-            case spaceLabelObject:
-              return 12;
-            case spaceObjectSensibility:
-              return 6;
-            case spaceObjectMouseMove:
-              return 3;
-            case spaceObjectDetail:
-              return 16;
-            }
-          break;
-        }
-
-        return 1;
+        return theme->GetSpaceHorizontal(space);
       }
 
       size_t Display::GetSpaceVertical(Space space) const
       {
-        switch (type) {
-          case typeTextual:
-            switch (space) {
-            case spaceWindowBorder:
-              return 0;
-            case spaceInterGroup:
-              return 0;
-            case spaceGroupIndent:
-              return 0;
-            case spaceInterObject:
-              return 0;
-            case spaceObjectBorder:
-              return 0;
-            case spaceIntraObject:
-              return 0;
-            case spaceLabelObject:
-              return 0;
-            case spaceObjectSensibility:
-              return 0;
-            case spaceObjectMouseMove:
-              return 1;
-            case spaceObjectDetail:
-              return 0;
-            }
-          break;
-          case  typeGraphical:
-            switch (space) {
-            case spaceWindowBorder:
-              return 12;
-            case spaceInterGroup:
-              return 18;
-            case spaceGroupIndent:
-              return 12;
-            case spaceInterObject:
-              return 6;
-            case spaceObjectBorder:
-              return 3;
-            case spaceIntraObject:
-              return 6;
-            case spaceLabelObject:
-              return 6;
-            case spaceObjectSensibility:
-              return 6;
-            case spaceObjectMouseMove:
-              return 3;
-            case spaceObjectDetail:
-              return 16;
-            }
-          break;
-        }
-
-        return 1;
+        return theme->GetSpaceVertical(space);
       }
 
       Display::TextDirection Display::GetDefaultTextDirection() const
