@@ -22,6 +22,9 @@
 #include <Lum/Base/Size.h>
 #include <Lum/Base/Util.h>
 
+#define DEFAULT_PROP_FONT_SIZE 12
+#define DEFAULT_FIXED_FONT_SIZE 13
+
 namespace Lum {
   namespace OS {
     namespace Base {
@@ -169,7 +172,8 @@ namespace Lum {
           button       =  7, //! graphical button frame
           box          =  8, //! box frame
           tabRider     =  9, //! "normal" tab rider
-          tab          = 10  //! "Normal" frame for complete tab
+          tab          = 10, //! "Normal" frame for complete tab
+          label        = 11  //! Draw focus frame only if draaw->focused
         };
 
       public:
@@ -188,11 +192,7 @@ namespace Lum {
       InternalImage::InternalImage(Type type)
       : width(0),height(0),alpha(false),drawCap(0),type(type)
       {
-        OS::FontExtent extent;
         int            unit;
-        OS::FontRef    font;
-
-        font=OS::display->GetFont();
 
         this->type=type;
 
@@ -232,7 +232,7 @@ namespace Lum {
           alpha=false;
         }
 
-        unit=(font->height/2>0) ? font->height/2 : 1;
+        unit=(DEFAULT_PROP_FONT_SIZE/2>0) ? DEFAULT_PROP_FONT_SIZE/2 : 1;
 
         switch (type) {
         case checkbox:
@@ -279,21 +279,14 @@ namespace Lum {
           width=unit;
           height=unit;
           break;
+        case led:
+          width=Lum::Base::RoundUpEven(7*unit / 4);
+          height=Lum::Base::RoundUpEven(7*unit / 4);
+          break;
         case comboButton:
           width=2*unit;
           height=2*unit;
           break;
-        case led:
-          if (OS::display->GetType()==OS::Display::typeTextual) {
-            font->StringExtent(L"*",extent);
-            height=extent.height;
-            width=extent.width;
-          }
-          else {
-            width=2*unit;
-            height=2*unit;
-          }
-          break;
         case treeCross:
           width=unit;
           height=unit;
@@ -352,98 +345,10 @@ namespace Lum {
 
       void InternalImage::Draw(OS::DrawInfo* draw, int x, int y, size_t width, size_t height)
       {
-        OS::FontExtent      extent;
         OS::DrawInfo::Point points[3];
         OS::FontRef         font=OS::display->GetFont();
 
         switch (type) {
-        case checkbox:
-          if (draw->disabled) {
-            draw->PushForeground(OS::Display::backgroundColor);
-          }
-          else {
-            draw->PushForeground(OS::Display::whiteColor);
-          }
-          draw->FillRectangle(x,y,width,height);
-          draw->PopForeground();
-
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
-          draw->DrawLine(x,y+height-1,x,y+1);
-          draw->DrawLine(x,y,x+width-1,y);
-          draw->PopForeground();
-
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
-          draw->DrawLine(x+1,y+height-2,x+1,y+2);
-          draw->DrawLine(x+1,y+1,x+width-2,y+1);
-          draw->PopForeground();
-
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
-          draw->DrawLine(x+width-1,y+1,x+width-1,y+height-1);
-          draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
-          draw->PopForeground();
-
-          draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
-          draw->DrawLine(x+width-2,y+2,x+width-2,y+height-2);
-          draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
-          draw->PopForeground();
-
-          if (draw->selected) {
-            if (draw->disabled) {
-              draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
-            }
-            else {
-              draw->PushForeground(OS::Display::blackColor);
-            }
-            draw->PushPen(2,OS::DrawInfo::penNormal);
-            draw->DrawLine(x+3,y+3,x+width-4,y+height-4);
-            draw->DrawLine(x+width-4,y+3,x+3,y+height-4);
-            draw->PopPen();
-            draw->PopForeground();
-          }
-          break;
-
-        case radio:
-          if (draw->disabled) {
-            draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
-          }
-          else {
-            draw->PushForeground(OS::Display::whiteColor);
-          }
-          draw->FillArc(x,y,width,height,0,360*64);
-          draw->PopForeground();
-
-          draw->PushPen(2,OS::DrawInfo::penNormal);
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
-          draw->DrawArc(x,y,width,height,45*64,180*64);
-          draw->PopForeground();
-          draw->PopPen();
-
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
-          draw->DrawArc(x+1,y+1,width-2,height-2,45*64,180*64);
-          draw->PopForeground();
-
-          draw->PushPen(2,OS::DrawInfo::penNormal);
-          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
-          draw->DrawArc(x,y,width,height,225*64,180*64);
-          draw->PopForeground();
-          draw->PopPen();
-
-          draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
-          draw->DrawArc(x+1,y+1,width-2,height-2,225*64,180*64);
-          draw->PopForeground();
-
-          if (draw->selected) {
-            if (draw->disabled) {
-              draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
-            }
-            else {
-              draw->PushForeground(OS::Display::blackColor);
-            }
-            draw->FillArc(x+4,y+4,width-8,height-8,0,360*64);
-            draw->PopForeground();
-          }
-          break;
-
         case hSliderKnob:
         case vSliderKnob:
           DrawRectangle(draw,x,y,width,height,false);
@@ -647,49 +552,6 @@ namespace Lum {
           draw->PopForeground();
           break;
 
-        case led:
-          if (OS::display->GetType()==OS::Display::typeTextual) {
-            draw->PushFont(font,0);
-            draw->PushForeground(OS::Display::textColor);
-            if (draw->selected) {
-              font->StringExtent(L"*",extent);
-              draw->DrawString(x+extent.left,y+font->ascent,L"*");
-            }
-            else {
-              font->StringExtent(L" ",extent);
-              draw->DrawString(x+extent.left,y+font->ascent,L" ");
-            }
-            draw->PopForeground();
-            draw->PopFont();
-          }
-          else {
-            if (draw->selected) {
-              if (OS::display->GetColorMode()==OS::Display::colorModeMonochrome) {
-                draw->PushForeground(OS::Display::whiteColor);
-              }
-              else {
-                draw->PushForeground(OS::Display::fillColor);
-              }
-              draw->FillArc(x,y,width-1,height-1,0*64,360*64);
-              draw->PopForeground();
-            }
-            else {
-              draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
-              draw->FillArc(x,y,width-1,height-1,0*64,360*64);
-              draw->PopForeground();
-            }
-
-            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
-            draw->DrawArc(x+width / 4,y+height / 4,
-                         width / 2,height / 2,60*64,90*64);
-            draw->PopForeground();
-
-            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
-            draw->DrawArc(x,y,width-1,height-1,0*64,360*64);
-            draw->PopForeground();
-          }
-          break;
-
         case treeCross:
           draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
           if (draw->selected) {
@@ -802,6 +664,13 @@ namespace Lum {
           leftBorder=2;
           rightBorder=2;
           break;
+        case label:
+          topBorder=1;
+          bottomBorder=1;
+          leftBorder=1;
+          rightBorder=1;
+          alpha=true;
+          break;
         }
 
         minWidth=leftBorder+rightBorder;
@@ -1069,6 +938,19 @@ namespace Lum {
 
           draw->PopForeground();
           break;
+
+        case label:
+          if (draw->focused) {
+            draw->PushForeground(OS::Display::textColor);
+            draw->PushDash("\002\002",2,OS::DrawInfo::fDash);
+            draw->DrawLine(x          ,y,      x+w-1,y);
+            draw->DrawLine(x+w-1,y,            x+w-1,y+h-1);
+            draw->DrawLine(x+w-1,y+h-1,x,            y+h-1);
+            draw->DrawLine(x          ,y+h-1,x,      y);
+            draw->PopDash();
+            draw->PopForeground();
+          }
+          break;
         }
       }
 
@@ -1188,6 +1070,7 @@ namespace Lum {
         fillNames[Display::menuEntryBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
         fillNames[Display::graphBackgroundFillIndex]="white";
         fillNames[Display::toolbarBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
+        fillNames[Display::labelBackgroundFillIndex]=fillNames[Display::backgroundFillIndex];
 
         for (size_t i=0; i<Display::fillCount; i++) {
           display->AllocateNamedColor(fillNames[i],fillColors[i]);
@@ -1235,9 +1118,8 @@ namespace Lum {
         frame[Display::groupFrameIndex]=new InternalFrame(InternalFrame::group3D);
         frame[Display::menuStripFrameIndex]=emptyFrame;
         frame[Display::menuPulldownFrameIndex]=emptyFrame;
+        frame[Display::labelFrameIndex]=new InternalFrame(InternalFrame::label);
 
-        image[Display::checkImageIndex]=new InternalImage(InternalImage::checkbox);
-        image[Display::radioImageIndex]=new InternalImage(InternalImage::radio);
         image[Display::hknobImageIndex]=new InternalImage(InternalImage::knob);
         image[Display::vknobImageIndex]=new InternalImage(InternalImage::knob);
         image[Display::arrowLeftImageIndex]=new InternalImage(InternalImage::arrowLeft);
@@ -1259,8 +1141,13 @@ namespace Lum {
         image[Display::topSliderImageIndex]=new InternalImage(InternalImage::sliderUnfilled);
         image[Display::bottomSliderImageIndex]=new InternalImage(InternalImage::sliderFilled);
         image[Display::menuDividerImageIndex]=new InternalImage(InternalImage::hLine);
-        image[Display::menuDividerImageIndex]=new InternalImage(InternalImage::arrowRight);
-        image[Display::ledImageIndex]=new InternalImage(InternalImage::led);
+        image[Display::menuSubImageIndex]=new InternalImage(InternalImage::arrowRight);
+        image[Display::menuCheckImageIndex]=new InternalImage(InternalImage::checkbox);
+        image[Display::menuRadioImageIndex]=new InternalImage(InternalImage::radio);
+        // positive
+        // default
+        // help
+        // close
       }
 
       DefaultTheme::~DefaultTheme()
@@ -1289,7 +1176,7 @@ namespace Lum {
 
       size_t DefaultTheme::GetProportionalFontSize() const
       {
-        return 12;
+        return DEFAULT_PROP_FONT_SIZE;
       }
 
       std::wstring DefaultTheme::GetFixedFontName() const
@@ -1299,17 +1186,230 @@ namespace Lum {
 
       size_t DefaultTheme::GetFixedFontSize() const
       {
-        return 13;
+        return DEFAULT_FIXED_FONT_SIZE;
       }
 
-      OS::Theme::ScrollKnobMode DefaultTheme::GetScrollKnobMode() const
+      void DefaultTheme::GetObjectSize(ObjectType object,
+                                       size_t& width,
+                                       size_t& height) const
       {
-        return OS::Theme::scrollKnobModeDouble;
+        int         unit;
+        OS::FontRef font;
+
+        font=OS::display->GetFont();
+
+        unit=(font->height/2>0) ? font->height/2 : 1;
+
+        switch (object) {
+        case objCheck:
+          width=2*unit;
+          height=2*unit;
+          break;
+        case objRadio:
+          width=Lum::Base::RoundUpEven(7*unit / 4);
+          height=Lum::Base::RoundUpEven(7*unit / 4);
+          break;
+        case objLED:
+          width=2*unit;
+          height=2*unit;
+          break;
+        }
       }
 
-      OS::Theme::ToolbarPosition DefaultTheme::GetToolbarPosition() const
+      bool DefaultTheme::NeedsObjectParentDraw(ObjectType object) const
       {
-        return OS::Theme::toolbarTop;
+        switch (object) {
+        case objRadio:
+          return true;
+          break;
+        case objCheck:
+          return false;
+          break;
+        case objLED:
+          return true;
+          break;
+        }
+        
+        assert(false);
+      }
+
+      void DefaultTheme::DrawObject(DrawInfo* draw,
+                                    ObjectType object,
+                                    int x, int y, size_t width, size_t height,
+                                    int cX, int cY, size_t cWidth, size_t cHeight)
+      {
+        switch (object) {
+        case objCheck:
+          if (draw->disabled) {
+            draw->PushForeground(OS::Display::backgroundColor);
+          }
+          else {
+            draw->PushForeground(OS::Display::whiteColor);
+          }
+          draw->FillRectangle(x,y,width,height);
+          draw->PopForeground();
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          draw->DrawLine(x,y+height-1,x,y+1);
+          draw->DrawLine(x,y,x+width-1,y);
+          draw->PopForeground();
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
+          draw->DrawLine(x+1,y+height-2,x+1,y+2);
+          draw->DrawLine(x+1,y+1,x+width-2,y+1);
+          draw->PopForeground();
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
+          draw->DrawLine(x+width-1,y+1,x+width-1,y+height-1);
+          draw->DrawLine(x+width-1,y+height-1,x,y+height-1);
+          draw->PopForeground();
+
+          draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
+          draw->DrawLine(x+width-2,y+2,x+width-2,y+height-2);
+          draw->DrawLine(x+width-2,y+height-2,x+1,y+height-2);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            if (draw->disabled) {
+              draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+            }
+            else {
+              draw->PushForeground(OS::Display::blackColor);
+            }
+            draw->PushPen(2,OS::DrawInfo::penNormal);
+            draw->DrawLine(x+3,y+3,x+width-4,y+height-4);
+            draw->DrawLine(x+width-4,y+3,x+3,y+height-4);
+            draw->PopPen();
+            draw->PopForeground();
+          }
+          break;
+
+        case objRadio:
+          if (draw->disabled) {
+            draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
+          }
+          else {
+            draw->PushForeground(OS::Display::whiteColor);
+          }
+          draw->FillArc(x,y,width,height,0,360*64);
+          draw->PopForeground();
+
+          draw->PushPen(2,OS::DrawInfo::penNormal);
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+          draw->DrawArc(x,y,width,height,45*64,180*64);
+          draw->PopForeground();
+          draw->PopPen();
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
+          draw->DrawArc(x+1,y+1,width-2,height-2,45*64,180*64);
+          draw->PopForeground();
+
+          draw->PushPen(2,OS::DrawInfo::penNormal);
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
+          draw->DrawArc(x,y,width,height,225*64,180*64);
+          draw->PopForeground();
+          draw->PopPen();
+
+          draw->PushForeground(OS::Display::backgroundColor); /* TODO: */
+          draw->DrawArc(x+1,y+1,width-2,height-2,225*64,180*64);
+          draw->PopForeground();
+
+          if (draw->selected) {
+            if (draw->disabled) {
+              draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->halfShadowColor);
+            }
+            else {
+              draw->PushForeground(OS::Display::blackColor);
+            }
+            draw->FillArc(x+4,y+4,width-8,height-8,0,360*64);
+            draw->PopForeground();
+          }
+          break;
+        case objLED:
+          if (draw->selected) {
+            if (OS::display->GetColorMode()==OS::Display::colorModeMonochrome) {
+              draw->PushForeground(OS::Display::whiteColor);
+            }
+            else {
+              draw->PushForeground(OS::Display::fillColor);
+            }
+            draw->FillArc(x,y,width-1,height-1,0*64,360*64);
+            draw->PopForeground();
+          }
+          else {
+            draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
+            draw->FillArc(x,y,width-1,height-1,0*64,360*64);
+            draw->PopForeground();
+          }
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shineColor);
+          draw->DrawArc(x+width / 4,y+height / 4,
+                        width / 2,height / 2,60*64,90*64);
+          draw->PopForeground();
+
+          draw->PushForeground(dynamic_cast<DefaultTheme*>(display->GetTheme())->shadowColor);
+          draw->DrawArc(x,y,width-1,height-1,0*64,360*64);
+          draw->PopForeground();
+          break;
+        }
+      }
+
+      size_t DefaultTheme::GetSpaceHorizontal(Display::Space space) const
+      {
+        switch (space) {
+        case Display::spaceWindowBorder:
+          return 12;
+        case Display::spaceInterGroup:
+          return 18;
+        case Display::spaceGroupIndent:
+          return 12;
+        case Display::spaceInterObject:
+          return 6;
+        case Display::spaceObjectBorder:
+          return 6;
+        case Display::spaceIntraObject:
+          return 6;
+        case Display::spaceLabelObject:
+          return 12;
+        case Display::spaceObjectDetail:
+          return 16;
+        }
+
+        return 1;
+      }
+
+      size_t DefaultTheme::GetSpaceVertical(Display::Space space) const
+      {
+        switch (space) {
+        case Display::spaceWindowBorder:
+          return 12;
+        case Display::spaceInterGroup:
+          return 18;
+        case Display::spaceGroupIndent:
+          return 12;
+        case Display::spaceInterObject:
+          return 6;
+        case Display::spaceObjectBorder:
+          return 3;
+        case Display::spaceIntraObject:
+          return 6;
+        case Display::spaceLabelObject:
+          return 6;
+        case Display::spaceObjectDetail:
+          return 16;
+        }
+
+        return 1;
+      }
+
+      size_t DefaultTheme::GetDragStartSensitivity() const
+      {
+        return 6;
+      }
+
+      size_t DefaultTheme::GetMouseClickHoldSensitivity() const
+      {
+        return 5;
       }
 
       size_t DefaultTheme::GetMinimalButtonWidth() const
@@ -1337,6 +1437,20 @@ namespace Lum {
         return 2;
       }
 
+      OS::Theme::ScrollKnobMode DefaultTheme::GetScrollKnobMode() const
+      {
+        return OS::Theme::scrollKnobModeDouble;
+      }
+
+      OS::Theme::ToolbarPosition DefaultTheme::GetToolbarPosition() const
+      {
+        return OS::Theme::toolbarTop;
+      }
+
+      bool DefaultTheme::ShowButtonImages() const
+      {
+        return true;
+      }
     }
   }
 }
