@@ -27,8 +27,6 @@ namespace Lum {
         : image(image)
       {
         switch (image) {
-        case Display::checkImageIndex:
-        case Display::radioImageIndex:
         case Display::hknobImageIndex:
         case Display::vknobImageIndex:
         case Display::arrowLeftImageIndex:
@@ -44,7 +42,6 @@ namespace Lum {
         case Display::hscaleKnobImageIndex:
         case Display::vscaleKnobImageIndex:
         case Display::closeImageIndex:
-        case Display::ledImageIndex:
         case Display::menuSubImageIndex:
           width=1;
           height=1;
@@ -98,7 +95,7 @@ namespace Lum {
           for (int j=y; j<y+h; ++j) {
 
             switch (image) {
-            case Display::checkImageIndex:
+            case Display::menuCheckImageIndex:
               draw->PushForeground(Display::textColor);
               if (draw->selected) {
                 draw->DrawString(i,j,L"X");
@@ -108,7 +105,7 @@ namespace Lum {
               }
               draw->PopForeground();
               break;
-            case Display::radioImageIndex:
+            case Display::menuRadioImageIndex:
               draw->PushForeground(Display::textColor);
               if (draw->selected) {
                 draw->DrawString(i,j,L"*");
@@ -199,14 +196,6 @@ namespace Lum {
             case Display::closeImageIndex:
               draw->DrawString(i,j,L"X");
               break;
-            case Display::ledImageIndex:
-              if (draw->selected) {
-                draw->DrawString(i,j,L"*");
-              }
-              else {
-                draw->DrawString(i,j,L"o");
-              }
-              break;
             case Display::comboDividerImageIndex:
             case Display::menuDividerImageIndex:
             case Display::positiveImageIndex:
@@ -659,9 +648,8 @@ namespace Lum {
         frame[Display::groupFrameIndex]=emptyFrame; // TODO
         frame[Display::menuStripFrameIndex]=emptyFrame;
         frame[Display::menuPulldownFrameIndex]=new TextFrame(Display::menuPulldownFrameIndex);
+        frame[Display::labelFrameIndex]=emptyFrame;
 
-        image[Display::checkImageIndex]=new TextImage(Display::checkImageIndex);
-        image[Display::radioImageIndex]=new TextImage(Display::radioImageIndex);
         image[Display::hknobImageIndex]=new TextImage(Display::hknobImageIndex);
         image[Display::vknobImageIndex]=new TextImage(Display::vknobImageIndex);
         image[Display::arrowLeftImageIndex]=new TextImage(Display::arrowLeftImageIndex);
@@ -683,8 +671,10 @@ namespace Lum {
         image[Display::topSliderImageIndex]=new TextImage(Display::topSliderImageIndex);
         image[Display::bottomSliderImageIndex]=new TextImage(Display::bottomSliderImageIndex);
         image[Display::menuDividerImageIndex]=new TextImage(Display::menuDividerImageIndex);
+        image[Display::menuSubImageIndex]=new TextImage(Display::menuSubImageIndex);
+        image[Display::menuCheckImageIndex]=new TextImage(Display::menuCheckImageIndex);
+        image[Display::menuRadioImageIndex]=new TextImage(Display::menuRadioImageIndex);
         image[Display::closeImageIndex]=new TextImage(Display::closeImageIndex);
-        image[Display::ledImageIndex]=new TextImage(Display::ledImageIndex);
       }
 
       Theme::~Theme()
@@ -724,14 +714,134 @@ namespace Lum {
         return 1;
       }
 
-      OS::Theme::ScrollKnobMode Theme::GetScrollKnobMode() const
+      void Theme::GetObjectSize(ObjectType object,
+                                size_t& width,
+                                size_t& height) const
       {
-        return OS::Theme::scrollKnobModeDouble;
+        switch (object) {
+        case objRadio:
+        case objCheck:
+        case objLED:
+          width=1;
+          height=1;
+          break;
+        }
       }
 
-      OS::Theme::ToolbarPosition Theme::GetToolbarPosition() const
+      bool Theme::NeedsObjectParentDraw(ObjectType object) const
       {
-        return OS::Theme::toolbarTop;
+        switch (object) {
+        case objRadio:
+        case objCheck:
+        case objLED:
+          return false;
+          break;
+        }
+      }
+
+      void Theme::DrawObject(DrawInfo* draw,
+                             ObjectType object,
+                             int x, int y, size_t width, size_t height,
+                             int cX, int cY, size_t cWidth, size_t cHeight)
+      {
+        draw->PushFont(OS::display->GetFont());
+        draw->PushForeground(Display::textColor);
+
+        for (int i=x; i<x+width; ++i) {
+          for (int j=y; j<y+height; ++j) {
+            switch (object) {
+            case objCheck:
+              draw->PushForeground(Display::textColor);
+              if (draw->selected) {
+                draw->DrawString(i,j,L"X");
+              }
+              else {
+                draw->DrawString(i,j,L"o");
+              }
+              draw->PopForeground();
+              break;
+            case objRadio:
+              draw->PushForeground(Display::textColor);
+              if (draw->selected) {
+                draw->DrawString(i,j,L"*");
+              }
+              else {
+                draw->DrawString(i,j,L"o");
+              }
+              draw->PopForeground();
+              break;
+            case objLED:
+              if (draw->selected) {
+                draw->DrawString(i,j,L"*");
+              }
+              else {
+                draw->DrawString(i,j,L"o");
+              }
+              break;
+            }
+          }
+        }
+
+        draw->PopForeground();
+        draw->PopFont();
+      }
+
+      size_t Theme::GetSpaceHorizontal(Display::Space space) const
+      {
+        switch (space) {
+        case Display::spaceWindowBorder:
+          return 0;
+        case Display::spaceInterGroup:
+          return 1;
+        case Display::spaceGroupIndent:
+          return 1;
+        case Display::spaceInterObject:
+          return 0;
+        case Display::spaceObjectBorder:
+          return 0;
+        case Display::spaceIntraObject:
+          return 1;
+        case Display::spaceLabelObject:
+          return 1;
+        case Display::spaceObjectDetail:
+          return 1;
+        }
+
+        return 1;
+      }
+
+      size_t Theme::GetSpaceVertical(Display::Space space) const
+      {
+        switch (space) {
+        case Display::spaceWindowBorder:
+          return 0;
+        case Display::spaceInterGroup:
+          return 0;
+        case Display::spaceGroupIndent:
+          return 0;
+        case Display::spaceInterObject:
+          return 0;
+        case Display::spaceObjectBorder:
+          return 0;
+        case Display::spaceIntraObject:
+          return 0;
+        case Display::spaceLabelObject:
+          return 0;
+        case Display::spaceObjectDetail:
+          return 0;
+        }
+
+        return 1;
+      }
+
+      size_t Theme::GetDragStartSensitivity() const
+      {
+        return 1;
+      }
+
+      size_t Theme::GetMouseClickHoldSensitivity() const
+      {
+        return 1;
       }
 
       size_t Theme::GetMinimalButtonWidth() const
@@ -759,6 +869,21 @@ namespace Lum {
         return 0;
       }
 
+      OS::Theme::ScrollKnobMode Theme::GetScrollKnobMode() const
+      {
+        return OS::Theme::scrollKnobModeDouble;
+      }
+
+      OS::Theme::ToolbarPosition Theme::GetToolbarPosition() const
+      {
+        return OS::Theme::toolbarTop;
+      }
+
+      bool Theme::ShowButtonImages() const
+      {
+        return false;
+      }
+
     }
   }
 }
