@@ -291,9 +291,6 @@ namespace Lum {
           grabHWND=dynamic_cast<Window*>(parent)->window;
 
           //display->StopContextHelp();
-          // Since windows does not send a focus out for our special popups, we do it manually
-          // TODO: Generate a special LostCapture trigger!
-          dynamic_cast<Window*>(parent)->TriggerFocusOut();
         }
         else {
           grabHWND=dynamic_cast<Display*>(OS::display)->appWindow;
@@ -474,9 +471,15 @@ namespace Lum {
 
         if ((type==typeMenu || type==typePopup) && parent!=NULL) {
           /* ignore */ ::ShowWindow(window,SW_SHOWNOACTIVATE);
+          if (this->parent!=NULL) {
+            dynamic_cast<Window*>(this->parent)->TriggerGrabCancel();
+          }
         }
         else if (type==typeSplash) {
           /* ignore */ ::ShowWindow(window,SW_SHOWNOACTIVATE);
+          if (this->parent!=NULL) {
+            dynamic_cast<Window*>(this->parent)->TriggerGrabCancel();
+          }
         }
         else {
           /* ignore */ ::ShowWindow(window,activate ? SW_SHOWNORMAL : SW_SHOWNOACTIVATE);
