@@ -1886,6 +1886,24 @@ namespace Lum {
     // no code
   }
 
+  void Scrollable::SetHAdjustment(Model::Adjustment* adjustment)
+  {
+    UnattachModel(hAdjustment->GetTopModel());
+
+    hAdjustment=adjustment;
+
+    AttachModel(hAdjustment->GetTopModel());
+  }
+
+  void Scrollable::SetVAdjustment(Model::Adjustment* adjustment)
+  {
+    UnattachModel(vAdjustment->GetTopModel());
+
+    vAdjustment=adjustment;
+
+    AttachModel(vAdjustment->GetTopModel());
+  }
+
   Model::Adjustment* Scrollable::GetHAdjustment() const
   {
     return hAdjustment.Get();
