@@ -19,26 +19,14 @@
 
 #include <Lum/Radio.h>
 
-#include <Lum/OS/Display.h>
+#include <Lum/OS/Theme.h>
 
 namespace Lum {
 
-  static Radio::Prefs *prefs=new ::Lum::Radio::Prefs();
-
-  Radio::Prefs::Prefs()
-  : ImageState::Prefs(L"Radio")
-  {
-    // no code
-  }
-
-  void Radio::Prefs::Initialize()
-  {
-    ImageState::Prefs::Initialize();
-
-    image=OS::display->GetImage(OS::Display::radioImageIndex);
-  }
+  static ImageState::Prefs *prefs=new ::Lum::ImageState::Prefs(L"Radio");
 
   Radio::Radio()
+   : ImageState(OS::Theme::objRadio)
   {
     SetPrefs(::Lum::prefs);
   }
