@@ -169,6 +169,7 @@ namespace Lum {
     SetController(::Lum::controller);
 
     SetCanFocus(true);
+    RequestFocus();
     SetRequestsKeyboard(true);
 
     cutAction->Disable();
@@ -783,46 +784,9 @@ namespace Lum {
 
   void String::DrawCursor()
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-    int          yOff=y+(height-font->height) / 2;
-    std::wstring value=GetValue();
+    int yOff=this->y+(height-font->height) / 2;
 
-    draw->PushFont(font,OS::Font::normal);
-    if (cursorVisible) {
-      if (OS::display->GetType()==OS::Display::typeTextual) {
-        draw->PushForeground(OS::Display::fillColor);
-        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
-        draw->PopForeground();
-        draw->PushForeground(OS::Display::fillTextColor);
-        draw->DrawString(cursorPos,yOff,value.substr(cursor,1));
-        draw->PopForeground();
-      }
-      else {
-        draw->PushForeground(OS::Display::tableTextColor);
-        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
-        draw->PopForeground();
-      }
-    }
-    else {
-      if (OS::display->GetType()==OS::Display::typeTextual) {
-        DrawBackground(cursorPos,yOff,1,y+font->height-1-yOff+1);
-        draw->PushForeground(OS::Display::tableTextColor);
-        draw->DrawString(cursorPos,yOff,value.substr(cursor,1));
-        draw->PopForeground();
-      }
-      else {
-        draw->PushClip(cursorPos,yOff,1,font->height);
-
-        DrawBackground(cursorPos,yOff,1,font->height);
-
-        draw->PushForeground(OS::Display::tableTextColor);
-        draw->DrawString(cursorPos,yOff+font->ascent,value.substr(cursor,1));
-        draw->PopForeground();
-
-        draw->PopClip();
-      }
-    }
-    draw->PopFont();
+    Redraw(cursorPos,yOff,1,y+font->height-1-yOff+1);
   }
 
   std::wstring String::GetValue() const
@@ -838,26 +802,31 @@ namespace Lum {
     }
   }
 
-  void String::TriggerCursorBlink(bool draw)
+  /**
+    Sets the cursor to visible, cancels old cursor blink
+    timer and starts new timer.
+
+    Expects calling code to refresh control afterwards.
+    This method does not trigger a redraw itself!
+   */
+  void String::TriggerCursorBlink()
   {
     cursorVisible=true;
     OS::display->RemoveTimer(blinkAction);
-
-    if (visible && draw) {
-      DrawCursor();
-    }
-
     OS::display->AddTimer(0,BLINK_MICRO,blinkAction);
   }
 
+  /**
+    Sets the cursor to hidden and cancels old cursor blink
+    timer.
+
+    Expects calling code to refresh control afterwards.
+    This method does not trigger a redraw itself!
+   */
   void String::StopCursorBlink()
   {
     cursorVisible=false;
     OS::display->RemoveTimer(blinkAction);
-
-    if (visible) {
-      DrawCursor();
-    }
   }
 
   void String::Draw(int x, int y, size_t w, size_t h)
@@ -1030,7 +999,7 @@ namespace Lum {
       DrawBackground(markAPos,this->y,markBPos-markAPos+1,height);
       draw->selected=false;
 
-      draw->PushClip(markAPos,yOff,markBPos-markAPos,height);
+      draw->PushClip(markAPos,yOff,markBPos-markAPos+1,height);
       draw->PushForeground(OS::Display::fillTextColor);
       draw->DrawString(textPos,yOff+font->ascent,string);
       draw->PopForeground();
@@ -1045,7 +1014,19 @@ namespace Lum {
 
     /* Drawing the cursor */
     if (selected && !Selected() && cursorVisible) {
-      DrawCursor();
+      if (OS::display->GetType()==OS::Display::typeTextual) {
+        draw->PushForeground(OS::Display::fillColor);
+        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
+        draw->PopForeground();
+        draw->PushForeground(OS::Display::fillTextColor);
+        draw->DrawString(cursorPos,yOff,string.substr(cursor,1));
+        draw->PopForeground();
+      }
+      else {
+        draw->PushForeground(OS::Display::tableTextColor);
+        draw->FillRectangle(cursorPos,yOff,1,y+font->height-1-yOff+1);
+        draw->PopForeground();
+      }
     }
 
     draw->PopClip();
@@ -1095,7 +1076,7 @@ namespace Lum {
       else {
         selected=true;
         cursor=GetCursorPos(event.x);
-        TriggerCursorBlink(false);
+        TriggerCursorBlink();
         ClearSelection();
         Redraw();
       }
@@ -1104,7 +1085,7 @@ namespace Lum {
     else if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.qualifier==0 && event.button==OS::MouseEvent::button2) {
       selected=true;
       cursor=GetCursorPos(event.x);
-      TriggerCursorBlink(false);
+      TriggerCursorBlink();
       ClearSelection();
       Redraw();
       OS::display->QuerySelection(GetWindow(),this);
@@ -1149,8 +1130,6 @@ namespace Lum {
 
   bool String::HandleKeys(const OS::KeyEvent& event)
   {
-    unsigned long qualifier;
-
     if (!model.Valid() || !model->IsEnabled() || model->IsNull()) {
       return false;
     }
@@ -1166,14 +1145,15 @@ namespace Lum {
       break;
     default:
       if (!readOnly) {
-        std::wstring tmp;
+        unsigned long qualifier;
+        std::wstring  name;
 
-        event.GetName(tmp);
+        event.GetName(name);
         qualifier=event.qualifier & ~(OS::qualifierShiftLeft|OS::qualifierShiftRight|OS::qualifierShift|OS::qualifierCapsLock);
-        if (event.text.length()>0 && /* ~CC.IsControl(event.text[0])*/
-            !((tmp==event.text) && (qualifier!=0))) {
+
+        if (!event.text.empty() && !(name==event.text && qualifier!=0) && event.text[0]>=32) {
           ActionInsertString(event.text);
-        return true;
+          return true;
         }
       }
     }
