@@ -50,6 +50,11 @@ namespace Lum {
     focus=OS::display->GetFrame(OS::Display::focusFrameIndex);
   }
 
+  TableView::FormatProvider::~FormatProvider()
+  {
+    // no code
+  }
+
   TableView::Alignment TableView::FormatProvider::GetAlignment(size_t /*column*/, size_t /*row*/) const
   {
     return left;
@@ -82,7 +87,7 @@ namespace Lum {
     autoVSize(false),
     currentPos(1),
     scrolling(false),
-    scrollRefresh(false),
+    scrollRefresh(true),
     scrollTimerAction(new Model::Action()),
     cx(0),
     cy(0),
@@ -93,6 +98,7 @@ namespace Lum {
     font(OS::display->GetFont())
   {
     SetCanFocus(true);
+    RequestFocus();
 
     SetPrefs(::Lum::prefs);
     SetController(::Lum::controller);
@@ -721,6 +727,7 @@ namespace Lum {
     size_t lh=0;
 
     if (GetLineBounds(line,ly,lh)) {
+      scrollRefresh=false;
       Redraw(this->x,ly,width,lh);
     }
   }
@@ -860,9 +867,9 @@ namespace Lum {
         if (scrolling) {
           Lum::OS::display->AddTimer(0,1000000/25,scrollTimerAction);
         }
-
       }
       else {
+        scrollRefresh=true;
         DrawRect(draw,y-this->y,h);
       }
     }
@@ -1142,8 +1149,8 @@ namespace Lum {
             ActionDoubleClick();
           }
 
-          Lum::OS::display->AddTimer(0,1000000/20,mouseTimerAction);
           mouseTimer.SetToNow();
+          Lum::OS::display->AddTimer(0,1000000/20,mouseTimerAction);
         }
       }
       else if (event.button==OS::MouseEvent::button4) {
@@ -1155,11 +1162,18 @@ namespace Lum {
 
       return true;
     }
-    else if (event.type==OS::MouseEvent::move && (event.qualifier & OS::MouseEvent::button1)) {
+    else if (event.IsGrabed() &&
+             event.type==OS::MouseEvent::move &&
+             (event.qualifier & OS::MouseEvent::button1)) {
       Lum::Base::SystemTime now;
 
       now.Sub(mouseTimer);
 
+      // Happens for unknown reason sometimes under windows!
+      if (now.GetTime()==0 && now.GetMicroseconds()==0) {
+        return true;
+      }
+
       int step=((cy-event.y)*1000000)/(now.GetMicroseconds()+1000000*now.GetTime());
 
       if (abs(step)<5) {
@@ -1177,7 +1191,7 @@ namespace Lum {
         vAdjustment->SetTop(vAdjustment->GetTop()+step);
       }
       else if (step<0) {
-        if (abs(step)<vAdjustment->GetTop()-1) {
+        if ((size_t)abs(step)<vAdjustment->GetTop()-1) {
           vAdjustment->SetTop(vAdjustment->GetTop()+step);
         }
         else {
@@ -1219,12 +1233,15 @@ namespace Lum {
       RedrawLine(refreshRow->row);
     }
     else if ((insertRow=dynamic_cast<const Model::Table::InsertRow*>(&msg))!=NULL) {
+      scrollRefresh=false;
       Redraw(); // TODO: Better calculate to be redrawn region...
     }
     else if ((deleteRow=dynamic_cast<const Model::Table::DeleteRow*>(&msg))!=NULL) {
+      scrollRefresh=false;
       Redraw(); // TODO: Better calculate to be redrawn region...
     }
     else if ((resizedColumn=dynamic_cast<const Model::Header::ResizedColumn*>(&msg))!=NULL) {
+      scrollRefresh=false;
       Redraw(); // TODO: Calculate rectangle to get redrawn...
     }
     else if ((fitColumn=dynamic_cast<const Model::Header::FitColumn*>(&msg))!=NULL) {
@@ -1250,9 +1267,7 @@ namespace Lum {
       else if (model==vAdjustment->GetTopModel()) {
         if (!scrolling) {
           scrolling=true;
-          scrollRefresh=true;
           Redraw();
-          scrollRefresh=false;
         }
       }
       else if (model==hAdjustment->GetTopModel()) {
@@ -1262,15 +1277,11 @@ namespace Lum {
         Redraw();
       }
       if (model==scrollTimerAction && scrollTimerAction->IsFinished()) {
-        scrollRefresh=true;
         Redraw();
-        scrollRefresh=false;
       }
       else if (model==mouseTimerAction && mouseTimerAction->IsFinished()) {
         vAdjustment->SetTop(currentPos);
-        scrollRefresh=true;
         Redraw();
-        scrollRefresh=false;
         Lum::OS::display->RemoveTimer(scrollTimerAction);
       }
       if (model==updateScrollerAction && updateScrollerAction->IsFinished()) {
