@@ -119,9 +119,8 @@ namespace Lum {
     hScroller->SetFlex(true,false);
     hScroller->SetModel(object->GetHAdjustment());
 
-    if (RequestedFocus()) {
+    if (object->RequestedFocus()) {
       /* Delegate focusing to the real table */
-      object->RequestFocus();
       UnrequestFocus();
     }
 
